@@ -30,7 +30,6 @@ from __future__ import absolute_import
 # Stdlib
 import argparse
 import os
-import sys
 
 # Snekchek
 from snekchek.config_gen import generate
@@ -53,7 +52,7 @@ def run_main(args, do_exit=True):
                            out_json=args.json,
                            files=args.files)
 
-    if "--skip-format" not in sys.argv:
+    if args.skip_format:
         for style in get_stylers():
             handler.run_linter(style())
 
@@ -104,6 +103,10 @@ def main():
                         help=u"generate snekrc",
                         action=u"store_true",
                         default=False)
+    parser.add_argument(u"--skip-format",
+                        help=u"skip formatters like isort and black",
+                        action=u"store_true",
+                        default=False)
 
     args = parser.parse_args()
 
